package com.rjconsultores.ventaboletos.web.gui.controladores.esquemaoperacional;

import java.sql.SQLException;
import java.sql.Time;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Checkbox;
import org.zkoss.zul.Combobox;
import org.zkoss.zul.Comboitem;
import org.zkoss.zul.Datebox;
import org.zkoss.zul.Intbox;
import org.zkoss.zul.Paging;
import org.zkoss.zul.Timebox;

import com.rjconsultores.ventaboletos.entidad.ClaseServicio;
import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.EsquemaCorrida;
import com.rjconsultores.ventaboletos.entidad.Marca;
import com.rjconsultores.ventaboletos.entidad.Ruta;
import com.rjconsultores.ventaboletos.exception.BusinessException;
import com.rjconsultores.ventaboletos.service.ClaseServicioService;
import com.rjconsultores.ventaboletos.service.ConstanteService;
import com.rjconsultores.ventaboletos.service.CorridaService;
import com.rjconsultores.ventaboletos.service.EsquemaCorridaService;
import com.rjconsultores.ventaboletos.service.FiscalService;
import com.rjconsultores.ventaboletos.service.MarcaService;
import com.rjconsultores.ventaboletos.service.RutaService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderConfiguracionCorrida;
import com.trg.search.Filter;

@Controller("selecionarServicosGerarController")
@Scope("prototype")
public class SelecionarServicosGerarController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;
	private static Logger log = LogManager.getLogger(SelecionarServicosGerarController.class);

	@Autowired
	private transient PagedListWrapper<EsquemaCorrida> plwEsquemaCorrida;
	@Autowired
	private MarcaService marcaService;
	@Autowired
	private FiscalService fiscalService;
	@Autowired
	private ClaseServicioService claseService;
	@Autowired
	private RutaService rutaService;
	@Autowired
	private ConstanteService constanteService;
	@Autowired
	private EsquemaCorridaService esquemaCorridaService;
	@Autowired
	private CorridaService corridaService;
	private MyListbox esquemaCorridaList;
	private Paging pagingEsquemaCorrida;
	private Datebox fecInicio;
	private Datebox fecFinal;
	private Datebox fecGeracaoInicial;
	private Datebox fecGeracaoFinal;
	private Combobox cmbClase;
	private Combobox cmbMarca;
	private Combobox cmbRuta;
	private Combobox cmbEmpresaCorrida;
	private Checkbox chkGerarPorMarca;
	private List<Empresa> lsEmpresa;
	private List<Marca> lsMarca;
	private List<ClaseServicio> lsClase;
	private List<Ruta> lsRuta;
	private Intbox txtID;
	private Intbox txtNumCorrida;
	private Timebox hora;
	private Set<EsquemaCorrida> selected;

	public Set<EsquemaCorrida> getSelected() {
		return selected;
	}

	public void setSelected(Set<EsquemaCorrida> selected) {
		this.selected = selected;
	}

	public List<ClaseServicio> getLsClase() {
		return lsClase;
	}

	public void setLsClase(List<ClaseServicio> lsClase) {
		this.lsClase = lsClase;
	}

	public List<Empresa> getLsEmpresa() {
		return lsEmpresa;
	}

	public void setLsEmpresa(List<Empresa> lsEmpresa) {
		this.lsEmpresa = lsEmpresa;
	}

	public List<Marca> getLsMarca() {
		return lsMarca;
	}

	public void setLsMarca(List<Marca> lsMarca) {
		this.lsMarca = lsMarca;
	}

	public List<Ruta> getLsRuta() {
		return lsRuta;
	}

	public void setLsRuta(List<Ruta> lsRuta) {
		this.lsRuta = lsRuta;
	}

	public void refreshLista() {
		HibernateSearchObject<EsquemaCorrida> busquedaCorrita =
				new HibernateSearchObject<EsquemaCorrida>(EsquemaCorrida.class,
						pagingEsquemaCorrida.getPageSize());

		busquedaCorrita.addFilterEqual("activo", Boolean.TRUE);

		Integer id = txtID.getValue();
		busquedaCorrita.addFilterEqual("esquemacorridaId", id);

		Integer numCorrida = txtNumCorrida.getValue();
		busquedaCorrita.addFilterEqual("numCorrida", numCorrida);

		Date dtHora = hora.getValue();
		if (dtHora != null) {
			Time time = new Time(dtHora.getTime());
			busquedaCorrita.addFilterEqual("horasalida", time);
		}

		Comboitem cbiClase = cmbClase.getSelectedItem();
		ClaseServicio claseServicio = null;
		if (cbiClase != null) {
			claseServicio = (ClaseServicio) cbiClase.getValue();
			busquedaCorrita.addFilterEqual("claseServicio", claseServicio);
		}

		Comboitem cbiMarca = cmbMarca.getSelectedItem();
		Marca marca = null;
		if (cbiMarca != null) {
			marca = (Marca) cbiMarca.getValue();
			busquedaCorrita.addFilterEqual("marca", marca);
		}

		Comboitem cbiRuta = cmbRuta.getSelectedItem();
		Ruta ruta = null;
		if (cbiRuta != null) {
			ruta = (Ruta) cbiRuta.getValue();
			busquedaCorrita.addFilterEqual("ruta", ruta);
		}

		Comboitem cbiEmpresa = cmbEmpresaCorrida.getSelectedItem();
		Empresa empresa = null;
		if (cbiEmpresa != null) {
			empresa = (Empresa) cbiEmpresa.getValue();
			busquedaCorrita.addFilterEqual("empresa", empresa);
		} else {
			busquedaCorrita.addFilterIn("empresa", lsEmpresa);
		}

		if (fecInicio.getValue() != null) {
			Date ini = fecInicio.getValue();
			GregorianCalendar gc = new GregorianCalendar();
			gc.setTime(ini);
			gc.set(Calendar.HOUR_OF_DAY, 0);
			gc.set(Calendar.MINUTE, 0);
			gc.set(Calendar.SECOND, 0);

			busquedaCorrita.addFilterGreaterOrEqual("esquemaOperacional.fecniciovigencia", gc.getTime());
		}

		if (fecFinal.getValue() != null) {
			Date fin = fecFinal.getValue();
			GregorianCalendar gc = new GregorianCalendar();
			gc.setTime(fin);
			gc.set(Calendar.HOUR_OF_DAY, 0);
			gc.set(Calendar.MINUTE, 0);
			gc.set(Calendar.SECOND, 0);

			busquedaCorrita.addFilterLessOrEqual("esquemaOperacional.fecfinvigencia", gc.getTime());
		}
		
		busquedaCorrita.addFilterOr( Filter.isNull("indCorridaDesativada"), Filter.equal("indCorridaDesativada", Boolean.FALSE));
		
		busquedaCorrita.addSortDesc("esquemacorridaId");

		plwEsquemaCorrida.init(busquedaCorrita, esquemaCorridaList, pagingEsquemaCorrida);

		if (esquemaCorridaList.getData().length == 0) {
			try {
				Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
						Labels.getLabel("selecionarServicosGerarController.window.title"),
						Messagebox.OK, Messagebox.INFORMATION);
			} catch (InterruptedException ex) {
			}
		}
		selected.clear();
	}

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		super.doAfterCompose(comp);
		selected = new HashSet<EsquemaCorrida>();

		lsEmpresa = UsuarioLogado.getUsuarioLogado().getEmpresa();
		lsMarca = marcaService.buscarMarcaPorEmpresa(UsuarioLogado.getUsuarioLogado().getEmpresa());
		lsClase = claseService.obtenerTodos();
		lsRuta = rutaService.obtenerTodos();

		esquemaCorridaList.setItemRenderer(new RenderConfiguracionCorrida());
	}

	public void onClick$btnPesquisa(Event ev) {
		refreshLista();
	}

	public void onClick$btnRefresh(Event ev) {
		refreshLista();
	}

	public void onCheck$chkGerarPorMarca(Event ev) {
		if(chkGerarPorMarca.isChecked()){
			limparGrid();
			limparFiltrosExcetoMarca();
		}
	}

	public void onClick$btnGerar(Event ev) throws InterruptedException {

		if (selected.isEmpty() && !chkGerarPorMarca.isChecked()) {
			Messagebox.show(Labels.getLabel("selecionarServicosGerarController.MSG.selecioneservicos"),
					Labels.getLabel("selecionarServicosGerarController.window.title"),
					Messagebox.OK, Messagebox.INFORMATION);

			return;
		}

		Date dataGeracaoInicial = fecGeracaoInicial.getValue();
		Date dataGeracaoFinal = fecGeracaoFinal.getValue();
		
		List<EsquemaCorrida> lsEsquemaCorrida =null;
		
		if(chkGerarPorMarca.isChecked() && cmbMarca.getSelectedItem() == null){
			Messagebox.show(Labels.getLabel("selecionarServicosGerarController.MSG.marcaNaoSelecionada"),
					Labels.getLabel("selecionarServicosGerarController.window.title"),
					Messagebox.OK, Messagebox.EXCLAMATION);
			return;
		}else if(chkGerarPorMarca.isChecked() && cmbMarca.getSelectedItem() != null){
			limparFiltrosExcetoMarca();
			limparGrid();
			
			Comboitem cbiMarca = cmbMarca.getSelectedItem();
			Marca marca = null;
			if (cbiMarca != null) {
				marca = (Marca) cbiMarca.getValue();
				lsEsquemaCorrida = esquemaCorridaService.buscarPorEmpresaCorridaAtiva(marca.getEmpresa(), dataGeracaoInicial, dataGeracaoFinal);
			}
		}

		
		if (lsEsquemaCorrida==null){
			lsEsquemaCorrida = new ArrayList<EsquemaCorrida>();
			
			for (Object o : selected) {
				EsquemaCorrida esquemaCorrida = (EsquemaCorrida) o;
				lsEsquemaCorrida.add(esquemaCorrida);
			} 
		}

		if (dataGeracaoInicial.after(dataGeracaoFinal)) {
			Messagebox.show(Labels.getLabel("selecionarServicosGerarController.MSG.dataInicialMaiorFinal"),
					Labels.getLabel("selecionarServicosGerarController.window.title"),
					Messagebox.OK, Messagebox.EXCLAMATION);
			return;
		}

		Long cantCorridasGeneradas;
		try {
			cantCorridasGeneradas = corridaService.generarCorridasSelecionadas(lsEsquemaCorrida, dataGeracaoInicial, dataGeracaoFinal);

			esquemaCorridaList.setData(new ArrayList<EsquemaCorrida>());

			Messagebox.show(Labels.getLabel("selecionarServicosGerarController.MSG.operacaoFinalizar", new Object[] { cantCorridasGeneradas }),
					Labels.getLabel("selecionarServicosGerarController.window.title"),
					Messagebox.OK, Messagebox.INFORMATION);

			if (constanteService.pafActivo()) {
				log.info("qtdP2=" + fiscalService.gerarRegistroP2_F2(lsEsquemaCorrida, dataGeracaoInicial, dataGeracaoFinal));
			}

		} catch (BusinessException e) {
			Messagebox.show(e.getLocalizedMessage(),
					Labels.getLabel("selecionarServicosGerarController.window.title"),
					Messagebox.OK, Messagebox.INFORMATION);
		} catch (SQLException e) {
			log.error("erro gerar registros paf",e);
		}

	}

	private void limparFiltrosExcetoMarca() {
		txtID.setValue(null);
		txtNumCorrida.setValue(null);
		cmbRuta.setSelectedItem(null);
		hora.setValue(null);
		cmbClase.setSelectedItem(null);
		cmbEmpresaCorrida.setSelectedItem(null);
		fecInicio.setValue(null);
		fecFinal.setValue(null);
	}

	private void limparGrid() {
		esquemaCorridaList.setData(new ArrayList<Object>());
		pagingEsquemaCorrida.setTotalSize(1);
	}

	public void onSelect$esquemaCorridaList() {
		int pos = 0;
		for (Object o : esquemaCorridaList.getData()) {
			EsquemaCorrida e = (EsquemaCorrida) o;
			if (esquemaCorridaList.getItemAtIndex(pos).isSelected()) {
				if (!selected.contains(e)) {
					selected.add(e);
				}
			} else {
				selected.remove(e);
			}
			pos++;
		}
	}

	public void onAfterRender$esquemaCorridaList() {
		if (esquemaCorridaList.getData() != null) {
			int pos = 0;
			for (Object o : esquemaCorridaList.getData()) {
				EsquemaCorrida e = (EsquemaCorrida) o;
				if (selected.contains(e)) {
					esquemaCorridaList.addItemToSelection(esquemaCorridaList.getItemAtIndex(pos));
				}
				pos++;
			}
		}
	}

	/**
	 * @return the chkGerarPorMarca
	 */
	public Checkbox getChkGerarPorMarca() {
		return chkGerarPorMarca;
	}

	/**
	 * @param chkGerarPorMarca the chkGerarPorMarca to set
	 */
	public void setChkGerarPorMarca(Checkbox chkGerarPorMarca) {
		this.chkGerarPorMarca = chkGerarPorMarca;
	}

}
