package com.rjconsultores.ventaboletos.web.utilerias.menu.item.seguridad;

import org.apache.commons.lang.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.context.ApplicationContext;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.util.Clients;
import org.zkoss.zul.Messagebox;

import com.rjconsultores.ventaboletos.service.ConstanteService;
import com.rjconsultores.ventaboletos.web.utilerias.api.ApiCallRunnable;
import com.rjconsultores.ventaboletos.web.utilerias.menu.DefaultItemMenuSistema;
import com.rjconsultores.ventaboletos.web.utilerias.spring.AppContext;

public class ItemMenuLimparCacheLocalidadesAPI extends DefaultItemMenuSistema {
	private static Logger log = LogManager.getLogger(ItemMenuLimparCacheLocalidadesAPI.class);
	

	public ItemMenuLimparCacheLocalidadesAPI() {
		super("indexController.mniLimparCacheLocalidadesAPI.label");
	}

	@Override
	public String getClaveMenu() {
		return "COM.RJCONSULTORES.ADMINISTRACION.GUI.SEGURIDAD.MENU.RECARREGARCACHELOCALIDADESAPI";
	}

	@Override
	public void ejecutar() {

		try {

			int resp = Messagebox.show(
					Labels.getLabel("limparCacheLocalidadesAPI.message.pergunta"),
					Labels.getLabel("limparCacheLocalidadesAPI.title"), Messagebox.YES | Messagebox.NO, Messagebox.QUESTION);

			if (resp == Messagebox.YES) {

				String[] urls = getURLSAPI();

				if (urls == null || urls.length == 0) {
					Clients.alert(org.zkoss.util.resource.Labels.getLabel("limparCacheLocalidadesAPI.message.naoconfigurado"),
							org.zkoss.util.resource.Labels.getLabel("limparCacheLocalidadesAPI.title"), Messagebox.INFORMATION);
					return;
				}

				for (String url : urls) {

					if (StringUtils.isBlank(url) || url.contains("|")) {
						Clients.alert(org.zkoss.util.resource.Labels.getLabel("limparCacheLocalidadesAPI.message.naoconfigurado"),
								org.zkoss.util.resource.Labels.getLabel("limparCacheLocalidadesAPI.title"), Messagebox.INFORMATION);
						return;
					}

					String tenant = StringUtils.substringBetween(url, "[", "]");
					if (tenant != null) {
						url = url.replaceAll("\\[.*?\\]", "");
					}
					String urlBase = url;
					url = montarUrlRequest(url);

					ApiCallRunnable cache = new ApiCallRunnable(url, tenant, urlBase );
					Thread thread = new Thread(cache);
					thread.start();
					thread.join();

					Clients.alert(cache.getRetorno(), org.zkoss.util.resource.Labels.getLabel("limparCacheLocalidadesAPI.title"), Messagebox.INFORMATION);
				}

			}

		} catch (Exception e) {
			Clients.alert(e.getMessage(),
					org.zkoss.util.resource.Labels.getLabel("limparCacheLocalidadesAPI.title"), Messagebox.ERROR);
			log.error(e.getMessage(), e);
		}

	}

	private String montarUrlRequest(String url) {

		url = url.toLowerCase();

		if (!url.endsWith("/")) {
			url += "/";
		}

		return url.concat("adm/limparCache");
	}

	private String[] getURLSAPI() {
		ApplicationContext appContext = AppContext.getApplicationContext();
		ConstanteService constanteService = (ConstanteService) appContext.getBean("constanteService");
		String constante = constanteService.buscarURLAPI();

		return constante == null ? null : constante.split("\\|");
	}
	
}
